@@ -1,3 +1,9 @@
+#
+# This file is part of LitePCIe.
+#
+# Copyright (c) 2015-2020 Florent Kermarrec <florent@enjoy-digital.fr>
+# SPDX-License-Identifier: BSD-2-Clause
+
 from migen import *
 
 from litex.soc.interconnect.csr import *
@@ -33,18 +39,13 @@ class LitePCIeMSI(Module, AutoCSR):
 
         # Generate MSI -----------------------------------------------------------------------------
         msi = Signal(width)
+        self.comb += self.source.valid.eq(msi != 0)
         self.sync += [
-            If(enable,
-                If(self.source.ready,
-                    msi.eq(self.irqs)
-                ).Else(
-                    msi.eq(msi | self.irqs)
-                )
-            ).Else(
-                msi.eq(0)
+            msi.eq(msi | (self.irqs & enable)),
+            If(self.source.ready,
+                msi.eq(self.irqs & enable)
             )
         ]
-        self.comb += self.source.valid.eq(msi != 0)
 
 # LitePCIeMSIMultiVector ---------------------------------------------------------------------------
 
